import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApiQueryString } from './../api-query-string';
import { IListDto } from './../backend/list-dto.interface';
import { MappedHttp } from './../mapped-rest/mapped-http';
import { IMapper } from './../mappers/mapper.interface';
import { QueryFilter } from './../query-filter';
import { IQueryFilter } from './../query-filter.interface';
import { IGetAllExpand } from './get-all-expand.interface';
import { IGetAllPagination } from './get-all-pagination.interface';
import { IGetAllQueryFilter } from './get-all-query-filter.interface';
import { IGetAllService } from './get-all-service.interface';
import { IGetAllUrlParam } from './get-all-url-param.interface';
/**
 * Classe utilitária responsável por controlar a consulta de todos os registros de uma entidade
 * @template Entity Entidade espelho recebida do backend
 * @template Dto Entidade convertida para objeto a ser utilizado na interface
 */
export declare class MappedGetAll<Entity, Dto> extends MappedHttp implements IGetAllService<Dto>, IGetAllPagination<Dto>, IGetAllQueryFilter, IGetAllExpand, IGetAllUrlParam {
    private httpClient;
    private _urlGetAll;
    private mapper;
    /** Utilitário para manipular parâmetros query na requisição */
    private apiQueryString;
    readonly queryFilter: IQueryFilter;
    /** URL completa do endpoint de GetAll */
    readonly urlGetAll: string;
    /** Array com os registros */
    private _items;
    readonly items: Array<any>;
    /** Página corrente */
    readonly page: number;
    /** Número de registros por página */
    pageSize: number;
    /** Indica se há mais registros */
    private _hasNext;
    readonly hasNext: boolean;
    /** Expansões para a consulta */
    readonly expands: string[];
    /** Parâmetros de URL */
    private _urlParams;
    readonly urlParams: string[];
    /** Propriedade que indica se deve ou não definir o cabeçalho 'X-Portinari-No-Error' */
    private _xTotvsNoError;
    readonly xTotvsNoError: boolean;
    /** Propriedade que indica se deve ou não definir o cabeçalho 'X-SL-Unidade-Id' */
    private _xSLUnidadeId;
    readonly xSLUnidadeId: boolean;
    /**
     * Método construtor que inicializa a classe utilitária
     * @param httpClient Injeção do HttpClient
     * @param _urlGetAll URL completa do endpoint de GetAll
     * @param mapper Classe que determina o mapeamento da entidade
     */
    constructor(httpClient: HttpClient, _urlGetAll: string, mapper: IMapper<IListDto<Entity>, IListDto<Dto>>, urlMapper?: IMapper<Array<any>, string>);
    /**
     * Método responsável por realizar a consulta dos registros
     * @return Retorno assíncrono dos registros buscados
     */
    getAll(): Observable<Array<Dto>>;
    /**
     * Método responsável por 'limpar' as parametrizações da consulta
     * e realizá-la novamente
     * @return Retorno assíncrono dos registros buscados
     */
    reset(apiQueryString?: ApiQueryString): Observable<Array<Dto>>;
    /**
     * Método responsável por retornar os registros da próxima página
     * @return Retorno assíncrono dos registros buscados
     */
    more(): Observable<Array<Dto>>;
    /**
     * Método responsável por definir os filtros por query que devem ser aplicados a consulta
     * @param queryFilter Classe que contém a definição dos filtros
     */
    setQueryFilter(queryFilter: QueryFilter): void;
    /**
     * Método responsável por definir os parâmetros de URL para a consulta
     * @param urlParams Lista de parâmetros
     */
    setUrlParams(...urlParams: string[]): void;
    /**
     * Método responsável por definir as expansões para a consulta
     * @param expands Lista de expansões
     */
    setExpands(...expands: string[]): void;
    /**
     * Método responsável por 'limpar' as parametrizações da consulta e os itens
     */
    resetSearch(): void;
    /**
     * Retorna a instância definindo o cabeçalho para não apresentar as
     * mensagens de erro conforme padrão do Guia de Implementação de API
     * (X-Portinari-No-Error)
     */
    withTotvsNoErrorHeader(): MappedGetAll<Entity, Dto>;
    /**
     * Retorna a instância definindo o cabeçalho para injetar a unidadeId
     */
    withUnidadeId(): MappedGetAll<Entity, Dto>;
    /**
     * Método responsável por retornar os parâmetros de Query da consulta
     */
    private getQueryString;
    /** Monta o cabeçalho da requisição */
    private getHeaders;
}
